==> ejc-businessplan-impl-3.0.0-20241021.063348-193-sources.jar: com/ejianc/business/busniessplan/bean/PlanprojectdetailEntity.java <==
package com.ejianc.business.busniessplan.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目商务策划立项子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_businessplan_planprojectdetail")
public class PlanprojectdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="tid")
    private java.lang.String tid;
    @TableField(value="tpid")
    private java.lang.String tpid;
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="category_and_name")
    private java.lang.String categoryAndName; // 类别及项目名称
    @TableField(value="initiate_reason")
    private java.lang.String initiateReason; // 立项理由及依据
    @TableField(value="initiate_date")
    private java.util.Date initiateDate; // 立项时间
    @TableField(value="cost_estimate")
    private java.math.BigDecimal costEstimate; // 成本估算(成本分析)(元)
    @TableField(value="report_amount")
    private java.math.BigDecimal reportAmount; // 上报金额(元)
    @TableField(value="target_amount")
    private java.math.BigDecimal targetAmount; // 策划目标金额(元)
    @TableField(value="complete_amount")
    private java.math.BigDecimal completeAmount; // 已完成目标金额(元)
    @TableField(value="estimate_profits")
    private java.math.BigDecimal estimateProfits; // 预计利润(元)
    @TableField(value="proposed_complete_time")
    private java.util.Date proposedCompleteTime; // 拟完成时间节点
    @TableField(value="complete_time")
    private java.util.Date completeTime; // 完成时间
    @TableField(value="supporting_details")
    private java.lang.String supportingDetails; // 证明资料明细
    @TableField(value="report_to_thismonth_progress")
    private java.math.BigDecimal reportToThismonthProgress; // 报公司截至本月进度(元)
    @TableField(value="first_responsible_person")
    private java.lang.String firstResponsiblePerson; // 第一责任人
    @TableField(value="main_responsible_person")
    private java.lang.String mainResponsiblePerson; // 主要负责人
    @TableField(value="final_complete_time")
    private java.util.Date finalCompleteTime; // (最后)完成时间
    @TableField(value="attention")
    private java.lang.String attention; // 推荐情况、存在问题、注意事项
    @TableField(value="plan_content")
    private java.lang.String planContent; // 策划内容
    @TableField(value="plan_category")
    private java.lang.String planCategory; // 策划类别
    @TableField(value="plan_type")
    private java.lang.String planType; // 策划类型
    @TableField(value="plan_status")
    private java.lang.String planStatus; // 策划状态
    @TableField(value="taken_measures")
    private java.lang.String takenMeasures; // 拟采取的措施
    @TableField(value="person_liable")
    private java.lang.String personLiable; // 责任人
    @TableField(value="proposed_implementation_time")
    private java.util.Date proposedImplementationTime; // 拟实施时间
    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * tid
     */
    public String getTid() {
        return tid;
    }

    /**
     * tid
     */
    public void setTid(String tid) {
        this.tid = tid;
    }
    /**
     * tpid
     */
    public String getTpid() {
        return tpid;
    }

    /**
     * tpid
     */
    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 类别及项目名称
     */
    public java.lang.String getCategoryAndName() {
        return categoryAndName;
    }

    /**
     * 类别及项目名称
     */
    public void setCategoryAndName(java.lang.String categoryAndName) {
        this.categoryAndName = categoryAndName;
    }
    /**
     * 立项理由及依据
     */
    public java.lang.String getInitiateReason() {
        return initiateReason;
    }

    /**
     * 立项理由及依据
     */
    public void setInitiateReason(java.lang.String initiateReason) {
        this.initiateReason = initiateReason;
    }
    /**
     * 立项时间
     */
    public java.util.Date getInitiateDate() {
        return initiateDate;
    }

    /**
     * 立项时间
     */
    public void setInitiateDate(java.util.Date initiateDate) {
        this.initiateDate = initiateDate;
    }
    /**
     * 成本估算(成本分析)(元)
     */
    public java.math.BigDecimal getCostEstimate() {
        return costEstimate;
    }

    /**
     * 成本估算(成本分析)(元)
     */
    public void setCostEstimate(java.math.BigDecimal costEstimate) {
        this.costEstimate = costEstimate;
    }
    /**
     * 上报金额(元)
     */
    public java.math.BigDecimal getReportAmount() {
        return reportAmount;
    }

    /**
     * 上报金额(元)
     */
    public void setReportAmount(java.math.BigDecimal reportAmount) {
        this.reportAmount = reportAmount;
    }
    /**
     * 策划目标金额(元)
     */
    public java.math.BigDecimal getTargetAmount() {
        return targetAmount;
    }

    /**
     * 策划目标金额(元)
     */
    public void setTargetAmount(java.math.BigDecimal targetAmount) {
        this.targetAmount = targetAmount;
    }
    /**
     * 已完成目标金额(元)
     */
    public java.math.BigDecimal getCompleteAmount() {
        return completeAmount;
    }

    /**
     * 已完成目标金额(元)
     */
    public void setCompleteAmount(java.math.BigDecimal completeAmount) {
        this.completeAmount = completeAmount;
    }
    /**
     * 预计利润(元)
     */
    public java.math.BigDecimal getEstimateProfits() {
        return estimateProfits;
    }

    /**
     * 预计利润(元)
     */
    public void setEstimateProfits(java.math.BigDecimal estimateProfits) {
        this.estimateProfits = estimateProfits;
    }
    /**
     * 拟完成时间节点
     */
    public java.util.Date getProposedCompleteTime() {
        return proposedCompleteTime;
    }

    /**
     * 拟完成时间节点
     */
    public void setProposedCompleteTime(java.util.Date proposedCompleteTime) {
        this.proposedCompleteTime = proposedCompleteTime;
    }
    /**
     * 完成时间
     */
    public java.util.Date getCompleteTime() {
        return completeTime;
    }

    /**
     * 完成时间
     */
    public void setCompleteTime(java.util.Date completeTime) {
        this.completeTime = completeTime;
    }
    /**
     * 证明资料明细
     */
    public java.lang.String getSupportingDetails() {
        return supportingDetails;
    }

    /**
     * 证明资料明细
     */
    public void setSupportingDetails(java.lang.String supportingDetails) {
        this.supportingDetails = supportingDetails;
    }
    /**
     * 报公司截至本月进度(元)
     */

    public java.math.BigDecimal getReportToThismonthProgress() {
        return reportToThismonthProgress;
    }

    /**
     * 报公司截至本月进度(元)
     */
    public void setReportToThismonthProgress(java.math.BigDecimal reportToThismonthProgress) {
        this.reportToThismonthProgress = reportToThismonthProgress;
    }
    /**
     * 第一责任人
     */
    public java.lang.String getFirstResponsiblePerson() {
        return firstResponsiblePerson;
    }

    /**
     * 第一责任人
     */
    public void setFirstResponsiblePerson(java.lang.String firstResponsiblePerson) {
        this.firstResponsiblePerson = firstResponsiblePerson;
    }
    /**
     * 主要负责人
     */
    public java.lang.String getMainResponsiblePerson() {
        return mainResponsiblePerson;
    }

    /**
     * 主要负责人
     */
    public void setMainResponsiblePerson(java.lang.String mainResponsiblePerson) {
        this.mainResponsiblePerson = mainResponsiblePerson;
    }
    /**
     * (最后)完成时间
     */
    public java.util.Date getFinalCompleteTime() {
        return finalCompleteTime;
    }

    /**
     * (最后)完成时间
     */
    public void setFinalCompleteTime(java.util.Date finalCompleteTime) {
        this.finalCompleteTime = finalCompleteTime;
    }
    /**
     * 推荐情况、存在问题、注意事项
     */
    public java.lang.String getAttention() {
        return attention;
    }

    /**
     * 推荐情况、存在问题、注意事项
     */
    public void setAttention(java.lang.String attention) {
        this.attention = attention;
    }

    public String getPlanContent() {
        return planContent;
    }

    public void setPlanContent(String planContent) {
        this.planContent = planContent;
    }

    public String getPlanCategory() {
        return planCategory;
    }

    public void setPlanCategory(String planCategory) {
        this.planCategory = planCategory;
    }

    public String getPlanType() {
        return planType;
    }

    public void setPlanType(String planType) {
        this.planType = planType;
    }

    public String getPlanStatus() {
        return planStatus;
    }

    public void setPlanStatus(String planStatus) {
        this.planStatus = planStatus;
    }

    public String getTakenMeasures() {
        return takenMeasures;
    }

    public void setTakenMeasures(String takenMeasures) {
        this.takenMeasures = takenMeasures;
    }

    public String getPersonLiable() {
        return personLiable;
    }

    public void setPersonLiable(String personLiable) {
        this.personLiable = personLiable;
    }

    public Date getProposedImplementationTime() {
        return proposedImplementationTime;
    }

    public void setProposedImplementationTime(Date proposedImplementationTime) {
        this.proposedImplementationTime = proposedImplementationTime;
    }
}

==> ejc-businessplan-impl-3.0.0-20251209.082428-236-sources.jar: com/ejianc/business/busniessplan/bean/PlanprojectdetailEntity.java <==
package com.ejianc.business.busniessplan.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目商务策划立项子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_businessplan_planprojectdetail")
public class PlanprojectdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="tid")
    private java.lang.String tid;
    @TableField(value="tpid")
    private java.lang.String tpid;
    @TableField(value="sort")
    private java.lang.Integer sort; // 序号
    @TableField(value="category_and_name")
    private java.lang.String categoryAndName; // 类别及项目名称
    @TableField(value="initiate_reason")
    private java.lang.String initiateReason; // 立项理由及依据
    @TableField(value="initiate_date")
    private java.util.Date initiateDate; // 立项时间
    @TableField(value="cost_estimate")
    private java.math.BigDecimal costEstimate; // 成本估算(成本分析)(元)
    @TableField(value="report_amount")
    private java.math.BigDecimal reportAmount; // 上报金额(元)
    @TableField(value="target_amount")
    private java.math.BigDecimal targetAmount; // 策划目标金额(元)
    @TableField(value="complete_amount")
    private java.math.BigDecimal completeAmount; // 已完成目标金额(元)
    @TableField(value="estimate_profits")
    private java.math.BigDecimal estimateProfits; // 预计利润(元)
    @TableField(value="proposed_complete_time")
    private java.util.Date proposedCompleteTime; // 拟完成时间节点
    @TableField(value="complete_time")
    private java.util.Date completeTime; // 完成时间
    @TableField(value="supporting_details")
    private java.lang.String supportingDetails; // 证明资料明细
    @TableField(value="report_to_thismonth_progress")
    private java.math.BigDecimal reportToThismonthProgress; // 报公司截至本月进度(元)
    @TableField(value="first_responsible_person")
    private java.lang.String firstResponsiblePerson; // 第一责任人
    @TableField(value="main_responsible_person")
    private java.lang.String mainResponsiblePerson; // 主要负责人
    @TableField(value="final_complete_time")
    private java.util.Date finalCompleteTime; // (最后)完成时间
    @TableField(value="attention")
    private java.lang.String attention; // 推荐情况、存在问题、注意事项
    @TableField(value="plan_content")
    private java.lang.String planContent; // 策划内容
    @TableField(value="plan_category")
    private java.lang.String planCategory; // 策划类别
    @TableField(value="plan_type")
    private java.lang.String planType; // 策划类型
    @TableField(value="plan_status")
    private java.lang.String planStatus; // 策划状态
    @TableField(value="taken_measures")
    private java.lang.String takenMeasures; // 拟采取的措施
    @TableField(value="person_liable")
    private java.lang.String personLiable; // 责任人
    @TableField(value="proposed_implementation_time")
    private java.util.Date proposedImplementationTime; // 拟实施时间
    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * tid
     */
    public String getTid() {
        return tid;
    }

    /**
     * tid
     */
    public void setTid(String tid) {
        this.tid = tid;
    }
    /**
     * tpid
     */
    public String getTpid() {
        return tpid;
    }

    /**
     * tpid
     */
    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    /**
     * 类别及项目名称
     */
    public java.lang.String getCategoryAndName() {
        return categoryAndName;
    }

    /**
     * 类别及项目名称
     */
    public void setCategoryAndName(java.lang.String categoryAndName) {
        this.categoryAndName = categoryAndName;
    }
    /**
     * 立项理由及依据
     */
    public java.lang.String getInitiateReason() {
        return initiateReason;
    }

    /**
     * 立项理由及依据
     */
    public void setInitiateReason(java.lang.String initiateReason) {
        this.initiateReason = initiateReason;
    }
    /**
     * 立项时间
     */
    public java.util.Date getInitiateDate() {
        return initiateDate;
    }

    /**
     * 立项时间
     */
    public void setInitiateDate(java.util.Date initiateDate) {
        this.initiateDate = initiateDate;
    }
    /**
     * 成本估算(成本分析)(元)
     */
    public java.math.BigDecimal getCostEstimate() {
        return costEstimate;
    }

    /**
     * 成本估算(成本分析)(元)
     */
    public void setCostEstimate(java.math.BigDecimal costEstimate) {
        this.costEstimate = costEstimate;
    }
    /**
     * 上报金额(元)
     */
    public java.math.BigDecimal getReportAmount() {
        return reportAmount;
    }

    /**
     * 上报金额(元)
     */
    public void setReportAmount(java.math.BigDecimal reportAmount) {
        this.reportAmount = reportAmount;
    }
    /**
     * 策划目标金额(元)
     */
    public java.math.BigDecimal getTargetAmount() {
        return targetAmount;
    }

    /**
     * 策划目标金额(元)
     */
    public void setTargetAmount(java.math.BigDecimal targetAmount) {
        this.targetAmount = targetAmount;
    }
    /**
     * 已完成目标金额(元)
     */
    public java.math.BigDecimal getCompleteAmount() {
        return completeAmount;
    }

    /**
     * 已完成目标金额(元)
     */
    public void setCompleteAmount(java.math.BigDecimal completeAmount) {
        this.completeAmount = completeAmount;
    }
    /**
     * 预计利润(元)
     */
    public java.math.BigDecimal getEstimateProfits() {
        return estimateProfits;
    }

    /**
     * 预计利润(元)
     */
    public void setEstimateProfits(java.math.BigDecimal estimateProfits) {
        this.estimateProfits = estimateProfits;
    }
    /**
     * 拟完成时间节点
     */
    public java.util.Date getProposedCompleteTime() {
        return proposedCompleteTime;
    }

    /**
     * 拟完成时间节点
     */
    public void setProposedCompleteTime(java.util.Date proposedCompleteTime) {
        this.proposedCompleteTime = proposedCompleteTime;
    }
    /**
     * 完成时间
     */
    public java.util.Date getCompleteTime() {
        return completeTime;
    }

    /**
     * 完成时间
     */
    public void setCompleteTime(java.util.Date completeTime) {
        this.completeTime = completeTime;
    }
    /**
     * 证明资料明细
     */
    public java.lang.String getSupportingDetails() {
        return supportingDetails;
    }

    /**
     * 证明资料明细
     */
    public void setSupportingDetails(java.lang.String supportingDetails) {
        this.supportingDetails = supportingDetails;
    }
    /**
     * 报公司截至本月进度(元)
     */

    public java.math.BigDecimal getReportToThismonthProgress() {
        return reportToThismonthProgress;
    }

    /**
     * 报公司截至本月进度(元)
     */
    public void setReportToThismonthProgress(java.math.BigDecimal reportToThismonthProgress) {
        this.reportToThismonthProgress = reportToThismonthProgress;
    }
    /**
     * 第一责任人
     */
    public java.lang.String getFirstResponsiblePerson() {
        return firstResponsiblePerson;
    }

    /**
     * 第一责任人
     */
    public void setFirstResponsiblePerson(java.lang.String firstResponsiblePerson) {
        this.firstResponsiblePerson = firstResponsiblePerson;
    }
    /**
     * 主要负责人
     */
    public java.lang.String getMainResponsiblePerson() {
        return mainResponsiblePerson;
    }

    /**
     * 主要负责人
     */
    public void setMainResponsiblePerson(java.lang.String mainResponsiblePerson) {
        this.mainResponsiblePerson = mainResponsiblePerson;
    }
    /**
     * (最后)完成时间
     */
    public java.util.Date getFinalCompleteTime() {
        return finalCompleteTime;
    }

    /**
     * (最后)完成时间
     */
    public void setFinalCompleteTime(java.util.Date finalCompleteTime) {
        this.finalCompleteTime = finalCompleteTime;
    }
    /**
     * 推荐情况、存在问题、注意事项
     */
    public java.lang.String getAttention() {
        return attention;
    }

    /**
     * 推荐情况、存在问题、注意事项
     */
    public void setAttention(java.lang.String attention) {
        this.attention = attention;
    }

    public String getPlanContent() {
        return planContent;
    }

    public void setPlanContent(String planContent) {
        this.planContent = planContent;
    }

    public String getPlanCategory() {
        return planCategory;
    }

    public void setPlanCategory(String planCategory) {
        this.planCategory = planCategory;
    }

    public String getPlanType() {
        return planType;
    }

    public void setPlanType(String planType) {
        this.planType = planType;
    }

    public String getPlanStatus() {
        return planStatus;
    }

    public void setPlanStatus(String planStatus) {
        this.planStatus = planStatus;
    }

    public String getTakenMeasures() {
        return takenMeasures;
    }

    public void setTakenMeasures(String takenMeasures) {
        this.takenMeasures = takenMeasures;
    }

    public String getPersonLiable() {
        return personLiable;
    }

    public void setPersonLiable(String personLiable) {
        this.personLiable = personLiable;
    }

    public Date getProposedImplementationTime() {
        return proposedImplementationTime;
    }

    public void setProposedImplementationTime(Date proposedImplementationTime) {
        this.proposedImplementationTime = proposedImplementationTime;
    }
}
